# TRONG-NGA PROXY TOOLS

### Setup docker and docker compose

+ Way1: Install docker and docker compose manually: [docker official doc](https://docs.docker.com/engine/install/ubuntu/)

+ Way2: Use [the official script for linux](https://docs.docker.com/engine/install/ubuntu/#install-using-the-convenience-script):

```
curl -fsSL https://get.docker.com -o get-docker.sh
sudo sh get-docker.sh
```

+ Otherwise, this simple script ([./install-docker.sh/](./install-docker.sh)) might work.

+ Check the installed version: (the docker-compose file generated by this tool use `depends_on` feature in docker compose v2, that might not work on compose v3). This check may be removed since we explicitly define the network dependency in the packetshare service (see [packetshare template](./templates/packetshare_template.yaml)). [Issue #1](https://github.com/vu-minh/trong-nga-proxy-tools/issues/1) is created for this.


```
$ docker version
Client: Docker Engine - Community
 Version:           28.0.1
 API version:       1.48
 Go version:        go1.23.6
 Git commit:        068a01e
 Built:             Wed Feb 26 10:41:12 2025
 OS/Arch:           linux/amd64
 Context:           default

Server: Docker Engine - Community
 Engine:
  Version:          28.0.1
  API version:      1.48 (minimum version 1.24)
  Go version:       go1.23.6
  Git commit:       bbd0a17
  Built:            Wed Feb 26 10:41:12 2025
  OS/Arch:          linux/amd64
  Experimental:     false
 containerd:
  Version:          1.7.25
  GitCommit:        bcc810d6b9066471b0b6fa75f557a15a1cbf31bb
 runc:
  Version:          1.2.4
  GitCommit:        v1.2.4-0-g6c52b3f
 docker-init:
  Version:          0.19.0
  GitCommit:        de40ad0
```

```
$ docker compose version
Docker Compose version v2.32.4-desktop.1
```

### Config and run:

+ `cd ./trong-nga-proxy-tool`
+ Edit `property.conf` to fill packetshare credential infos.
+ Edit `proxy.txt` to fill the list of proxy that will be used (format: `proxy_host:proxy_port:username:password`).

+ Run `./run.sh` for a full run. Make sure `run.sh` is executable (`chmod +x ./run.sh`). In the case where `docker-compose.yaml` file is good and we only want to start the docker container, use `./run.sh --quick`.

+ Stop the running containers: `docker compose stop`.

+ Remove all containers: `docker compose down`.


### Monitoring

+ Check running containers using [`docker compose ps` command](https://docs.docker.com/reference/cli/docker/compose/ps/)

```
$ docker compose ps --all
NAME                         IMAGE                        COMMAND                  SERVICE                       CREATED          STATUS          PORTS
packetshae-108.165.110.245   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.245   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.246   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.246   53 seconds ago   Up 46 seconds   
packetshae-108.165.110.247   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.247   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.248   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.248   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.249   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.249   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.250   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.250   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.251   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.251   53 seconds ago   Up 46 seconds   
packetshae-108.165.110.252   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.252   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.253   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.253   53 seconds ago   Up 45 seconds   
packetshae-108.165.110.254   packetshare/packetshare      "/app/Packetshare -a…"   packetshare-108.165.110.254   53 seconds ago   Up 45 seconds   
tun2socks-108.165.110.245    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.245     54 seconds ago   Up 49 seconds   
tun2socks-108.165.110.246    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.246     54 seconds ago   Up 49 seconds   
tun2socks-108.165.110.247    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.247     54 seconds ago   Up 48 seconds   
tun2socks-108.165.110.248    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.248     54 seconds ago   Up 48 seconds   
tun2socks-108.165.110.249    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.249     54 seconds ago   Up 49 seconds   
tun2socks-108.165.110.250    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.250     54 seconds ago   Up 49 seconds   
tun2socks-108.165.110.251    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.251     54 seconds ago   Up 49 seconds   
tun2socks-108.165.110.252    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.252     54 seconds ago   Up 48 seconds   
tun2socks-108.165.110.253    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.253     54 seconds ago   Up 48 seconds   
tun2socks-108.165.110.254    xjasonlyu/tun2socks:v2.5.2   "/entrypoint.sh"         tun2socks-108.165.110.254     54 seconds ago   Up 49 seconds
```