#!/bin/bash
set -o errexit -o pipefail -o noclobber -o nounset +x

###############################################################################
# variables for global files
PROPERTY_FILE="property.conf"
PROXY_FILE="proxy.txt"
BLACKLIST_FILE="blacklist.txt"

# variable for packetshare info, to be load from property file
PACKETSHARE_EMAIL=
PACKETSHARE_PASSWORD=

###############################################################################
# Show tool title
echo
cat title.txt
echo

# Load util functions and other global variables for coloring text
# shellcheck source=utils.sh
source utils.sh

###############################################################################
# Load property file and check if the needed params are loaded
load_properties $PROPERTY_FILE
echo "Packetshare account: $PACKETSHARE_EMAIL"
if [[ (! $PACKETSHARE_EMAIL) || (! $PACKETSHARE_PASSWORD) ]]; then
    echo -e "${RED} Cannot load Packetshare Email/Password ${NOCOLOUR}"
    exit 1
fi

block_domains_cmds=$(build_iptables_blacklist_cmds $BLACKLIST_FILE)

###############################################################################
# Check if we need to re-run all
if [[ "${1-default}" == "--quick" ]]; then
    echo -e "Do not rebuild docker compose file\n"
    docker_compose_file='./docker-compose.yaml'
else
    # Load the functions used to build docker containers
    # shellcheck source=build-docker-compose-file.sh
    source build-docker-compose-file.sh

    # Before building the containers, pre-pull the tun2socks and packetshare docker images
    docker image pull xjasonlyu/tun2socks:v2.5.2
    docker image pull packetshare/packetshare

    # Build the docker compose file
    docker_compose_file=$(
        build_docker_compose_file $PROXY_FILE "$PACKETSHARE_EMAIL" "$PACKETSHARE_PASSWORD" "$block_domains_cmds"
    )
fi

###############################################################################
# Create and run the docker container using `docker compose`
# Make sure the docker compose exist
if ! [ -f "${docker_compose_file}" ]; then
    echo -e "${RED} 'docker-compose.yaml' does not exist in the current directory." >&2
    echo -e "${RED} Re-run the tool WITHOUT '--quick' option. Should use: './run'" >&2
    exit 1
fi

# Run the docker compose in daemond
docker compose -f "$docker_compose_file" up -d
