#!/bin/bash

# Colours
# shellcheck disable=SC2034  # Variables used in other scipts
RED="\033[0;31m"
GREEN="\033[0;32m"
YELLOW="\033[0;33m"
NOCOLOUR="\033[0m"

# Read the properties file and export variables to the current shell
load_properties() {
    property_file="${1}"
    echo -e "\nLoading properties from $property_file" >&2

    while IFS= read -r line; do
        # Ignore lines that start with #
        if [[ $line != '#'* ]]; then
            # Split the line at the first occurrence of =
            key="${line%%=*}"
            value="${line#*=}"
            # Trim leading and trailing whitespace from key and value
            key="${key%"${key##*[![:space:]]}"}"
            value="${value%"${value##*[![:space:]]}"}"
            # Ignore lines without a value after =
            if [[ -n $value ]]; then
                # Replace variables with their values
                value=$(eval "echo $value")
                # Export the key-value pairs as variables
                export "$key"="$value"
            fi
        fi
    done <"$property_file"
}


# Build iptables command to drop traffic comming from any domain in the given blacklist_file
#
# Usage:
#   build_iptables_blacklist_cmds blacklist_file
#
# Return: the iptables commands (separated by ';') concatenated into a string
build_iptables_blacklist_cmds() {
    blacklist_file="$1"
    echo -e "\nProcessing blacklist file $blacklist_file" >&2

    block_commands=""
    block_count=0

    while IFS= read -r block_line; do
        # Ignore empty lines or lines that start with #
        if [[ $block_line && $block_line != '#'* ]]; then
            block_commands+=" iptables -A INPUT -m string --string '$block_line' --algo bm -j DROP; "
            ((block_count+=1))
        fi
    done <"$blacklist_file"

    echo -e ">>>>${GREEN} [$block_count] domains will be blocked by iptables.${NOCOLOUR}\n" >&2

    # Return the created commands
    echo "$block_commands"
}